//
//  ViewController.m
//  AppointmentOverlapTest
//
//  Created by Developer Support on 6/11/14.
//  Copyright (c) 2014 Developer Support. All rights reserved.
//

#import "ViewController.h"
#import <IG/IG.h>

@interface ViewController () <IGCalendarAppointmentDataSource>
{
    NSMutableArray *_appts;
    IGCalendarView *_calendar;
    NSMutableArray *_dataSources;
}
@end
@implementation ViewController
- (void)viewDidLoad
{
    [super viewDidLoad];
    _appts = [self generateAppointments:500];
    _calendar = [[IGCalendarView alloc] initWithFrame:self.view.bounds];
    _calendar.autoresizingMask = UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight;
    _calendar.minYear = 2014;
    _calendar.maxYear = 2014;
    _calendar.displayBackButton = NO;
    _calendar.displayTitleBar = YES;
    [_calendar setTranslatesAutoresizingMaskIntoConstraints:NO];
    [self.view addSubview:_calendar];
    _dataSources = [[NSMutableArray alloc]init];
    [_dataSources addObject:self];
    _calendar.appointmentDataSources = _dataSources;
}
-(void)calendarView:(IGCalendarView *)calView asyncAppointmentRequest:(IGCalendarAppointmentRequest *)request ofType:(IGCalendarAppointmentRequestType)requestType
{
    [[[NSOperationQueue alloc]init] addOperation:[NSBlockOperation blockOperationWithBlock:^(void)
                                                  {
                                                      NSTimeInterval min = [request.start timeIntervalSince1970];
                                                      NSTimeInterval max = [request.end timeIntervalSince1970];
                                                      NSMutableArray* returnAppts = [[NSMutableArray alloc]init];
                                                      for(NSDictionary* appt in _appts)
                                                      {
                                                          NSDate* startTime = appt[@"start"];
                                                          NSTimeInterval current = [startTime timeIntervalSince1970];
                                                          if(current >= min && current <= max)
                                                          {
                                                              IGCalendarAppointment* calAppt = [[IGCalendarAppointment alloc]init];
                                                              calAppt.startTime = startTime;
                                                              calAppt.endTime = appt[@"end"];
                                                              calAppt.location = appt[@"location"];
                                                              calAppt.title = appt[@"title"];
                                                              [returnAppts addObject:calAppt];
                                                          }
                                                      }
                                                      [[NSOperationQueue mainQueue] addOperation: [NSBlockOperation blockOperationWithBlock:^(void)
                                                                                                   {
                                                                                                       NSArray* appts = [NSArray arrayWithArray:returnAppts];
                                                                                                       [request provideAppointments:appts];
                                                                                                   }]];
                                                  }]];
}
- (UIColor *)colorForAppointmentsInIGCalendarView:(IGCalendarView *)calView
{
    return [UIColor redColor];
}
-(NSMutableArray *)generateAppointments:(int)count
{
    NSString *dateString, *month, *day, *year, *time, *location, *title;
    NSArray *titles = @[@"Webinar About", @"Conference Covering", @"Meeting About", @"Meeting With"];
    NSArray *subjects = @[@"Apple", @"Development", @"Engineering", @"iOS", @"Marketing", @"NucliOS", @"Sales"];
    NSArray *locations = @[@"Head Quarters", @"London, UK", @"Montevideo, UY", @"Tokoyo, JP"];
    NSMutableArray *appointments = [[NSMutableArray alloc] init];
    for (int j = 0; j < count; j++)
    {
        NSMutableDictionary *appointment = [[NSMutableDictionary alloc] init];
        month = [NSString stringWithFormat:@"%d", arc4random_uniform(12) + 1];
        day = [NSString stringWithFormat:@"%d", arc4random_uniform(27) + 1];
        year = @"2014";
        time = [NSString stringWithFormat:@"%c%c:%c%c PM",
                arc4random_uniform(1) + 48,
                arc4random_uniform(9) + 48,
                arc4random_uniform(5) + 48,
                arc4random_uniform(9) + 48];
        location = [NSString stringWithFormat:@"%@",
                    [locations objectAtIndex:arc4random_uniform(locations.count)]];
        title = [NSString stringWithFormat:@"%@ %@",
                 [titles objectAtIndex:arc4random_uniform(titles.count)],
                 [subjects objectAtIndex:arc4random_uniform(subjects.count)]];
        NSDateFormatter *df = [[NSDateFormatter alloc] init];
        [df setDateFormat:@"MM-dd-yyyy hh:mm a"];
        dateString = [NSString stringWithFormat:@"%@-%@-%@ %@", month, day, year, time];
        NSDate *startDate = [df dateFromString: dateString];
        NSDate *endDate = [startDate dateByAddingTimeInterval:(60 * (arc4random_uniform(180) + 60))];
        [appointment setObject:startDate forKey:@"start"];
        [appointment setObject:endDate forKey:@"end"];
        [appointment setObject:title forKey:@"title"];
        [appointment setObject:location forKey:@"location"];
        [appointments addObject:appointment];
    }
    return appointments;
}
@end
